@@ -2,25 +2,12 @@
     kmime_content.cpp
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001 the KMime authors.
+    SPDX-FileCopyrightText: 2001 the KMime authors.
     See file AUTHORS for details
-    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+    SPDX-FileCopyrightText: 2006 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -47,7 +34,6 @@
 #include <KLocalizedString>
 
 #include <QTextCodec>
-#include <QByteArray>
 
 using namespace KMime;
 
@@ -499,7 +485,7 @@ void Content::addContent(Content *c, bool prepend)
     // If this message is single-part; make it multipart first.
     if (d->multipartContents.isEmpty() && !contentType()->isMultipart()) {
         // The current body will be our first sub-Content.
-        Content *main = new Content(this);
+        auto *main = new Content(this);
 
         // Move the MIME headers to the newly created sub-Content.
         // NOTE: The other headers (RFC5322 headers like From:, To:, as well as X-headers
@@ -833,7 +819,7 @@ Content *Content::parent() const
 
 Content *Content::topLevel() const
 {
-    Content *top = const_cast<Content *>(this);
+    auto *top = const_cast<Content *>(this);
     Content *c = parent();
     while (c) {
         top = c;
@@ -932,7 +918,7 @@ bool ContentPrivate::parseUuencoded(Content *q)
         // Add the plain text part first.
         Q_ASSERT(multipartContents.isEmpty());
         {
-            Content *c = new Content(q);
+            auto *c = new Content(q);
             c->contentType()->setMimeType("text/plain");
             c->contentTransferEncoding()->setEncoding(Headers::CE7Bit);
             c->setBody(uup.textPart());
@@ -941,7 +927,7 @@ bool ContentPrivate::parseUuencoded(Content *q)
 
         // Now add each of the binary parts as sub-Contents.
         for (int i = 0; i < uup.binaryParts().count(); ++i) {
-            Content *c = new Content(q);
+            auto *c = new Content(q);
             c->contentType()->setMimeType(uup.mimeTypes().at(i));
             c->contentType()->setName(QLatin1String(uup.filenames().at(i)), QByteArray(/*charset*/));
             c->contentTransferEncoding()->setEncoding(Headers::CEuuenc);
@@ -988,7 +974,7 @@ bool ContentPrivate::parseYenc(Content *q)
         // Add the plain text part first.
         Q_ASSERT(multipartContents.isEmpty());
         {
-            Content *c = new Content(q);
+            auto *c = new Content(q);
             c->contentType()->setMimeType("text/plain");
             c->contentTransferEncoding()->setEncoding(Headers::CE7Bit);
             c->setBody(yenc.textPart());
@@ -997,7 +983,7 @@ bool ContentPrivate::parseYenc(Content *q)
 
         // Now add each of the binary parts as sub-Contents.
         for (int i = 0; i < yenc.binaryParts().count(); i++) {
-            Content *c = new Content(q);
+            auto *c = new Content(q);
             c->contentType()->setMimeType(yenc.mimeTypes().at(i));
             c->contentType()->setName(QLatin1String(yenc.filenames().at(i)), QByteArray(/*charset*/));
             c->contentTransferEncoding()->setEncoding(Headers::CEbinary);
@@ -1040,7 +1026,7 @@ bool ContentPrivate::parseMultipart(Content *q)
     body.clear();
     const auto parts = mpp.parts();
     for (const QByteArray &part : parts) {
-        Content *c = new Content(q);
+        auto *c = new Content(q);
         c->setContent(part);
         c->setFrozen(frozen);
         c->parse();
